@@ -6,6 +6,7 @@ from doctest import (
     DocTestParser as BaseDocTestParser,
     DocTestRunner as BaseDocTestRunner,
     Example as DocTestExample,
+    OutputChecker as BaseOutputChecker,
     _unittest_reportflags,
     register_optionflag
 )
@@ -15,7 +16,7 @@ from ..region import Region
 
 
 def make_literal(literal):
-    return re.compile(literal+r"((['\"])[^\2]*\2)", re.MULTILINE)
+    return re.compile(literal+r"((['\"])[^\2]*?\2)", re.MULTILINE)
 
 
 BYTE_LITERAL = make_literal('b')
@@ -37,11 +38,38 @@ class DocTest(BaseDocTest):
         self.globs = globs
 
 
+class OutputChecker(BaseOutputChecker):
+
+    def __init__(self, encoding):
+        self.encoding = encoding
+
+    def _decode(self, got):
+        decode = getattr(got, 'decode', None)
+        if decode is None:
+            return got
+        return decode(self.encoding)
+
+    def check_output(self, want, got, optionflags):
+        return BaseOutputChecker.check_output(
+            self, want, self._decode(got), optionflags
+        )
+
+    def output_difference(self, example, got, optionflags):
+        return BaseOutputChecker.output_difference(
+            self, example, self._decode(got), optionflags
+        )
+
+
 class DocTestRunner(BaseDocTestRunner):
 
-    def __init__(self, optionflags=0):
+    def __init__(self, optionflags, encoding):
         optionflags |= _unittest_reportflags
-        BaseDocTestRunner.__init__(self, verbose=False, optionflags=optionflags)
+        BaseDocTestRunner.__init__(
+            self,
+            checker=OutputChecker(encoding),
+            verbose=False,
+            optionflags=optionflags,
+        )
 
     def _failure_header(self, test, example):
         return ''
@@ -63,19 +91,18 @@ class DocTestParser(BaseDocTestParser):
     :param optionflags: 
         :ref:`doctest option flags<option-flags-and-directives>` to use
         when evaluating the examples found by this parser.
+
+    :param encoding:
+        If on Python 2, this encoding will be used to decode the string
+        resulting from execution of the examples.
     """
-    def __init__(self, optionflags=0):
-        self.runner = DocTestRunner(optionflags=optionflags)
+    def __init__(self, optionflags=0, encoding='utf-8'):
+        self.runner = DocTestRunner(optionflags, encoding)
 
     def __call__(self, document):
         # a cut down version of doctest.DocTestParser.parse:
 
         text = document.text
-        first_tab = text.find('\t')
-        if first_tab != -1:
-            raise ValueError('tabs are not supported, first one found at '+(
-                document.line_column(first_tab)
-            ))
         # If all lines begin with the same indentation, then strip it.
         min_indent = self._min_indent(text)
         if min_indent > 0:
